fsds package
============

.. automodule:: fsds
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   fsds.041320PT
   fsds.070620FT
   fsds.jmi
   fsds.pandemic

Submodules
----------

fsds.datasets module
--------------------

.. automodule:: fsds.datasets
   :members:
   :undoc-members:
   :show-inheritance:

fsds.default module
-------------------

.. automodule:: fsds.default
   :members:
   :undoc-members:
   :show-inheritance:

fsds.fsds module
----------------

.. automodule:: fsds.fsds
   :members:
   :undoc-members:
   :show-inheritance:

fsds.imports module
-------------------

.. automodule:: fsds.imports
   :members:
   :undoc-members:
   :show-inheritance:

fsds.imports\_legacy module
---------------------------

.. automodule:: fsds.imports_legacy
   :members:
   :undoc-members:
   :show-inheritance:

fsds.quick\_refs module
-----------------------

.. automodule:: fsds.quick_refs
   :members:
   :undoc-members:
   :show-inheritance:
